corrLib
=======

.. automodule:: myimagelib.corrLib





   .. rubric:: Autocorrelation functions

   .. autosummary::
      :toctree: corrLib

      corrI
      corrS
      distance_corr
      autocorr1d
      vacf_piv

   .. rubric:: Density fluctuations

   .. autosummary::
     :toctree: corrLib

      density_fluctuation
      df2
      df2_
      plot_gnf
      local_df

   .. rubric:: Energy spectra

   .. autosummary::
     :toctree: corrLib

      compute_energy_density
      compute_wavenumber_field
      energy_spectrum

   .. rubric:: Flow field analysis

   .. autosummary::
     :toctree: corrLib

      div_field
      divergence
      vorticity
      convection

   .. rubric:: Misc

   .. autosummary::
     :toctree: corrLib
     
      divide_windows
      divide_stack
